@@ -53,8 +53,9 @@ sub _patch_command {
 sub awx_grep_dlls {
     my( $self, $libdir, $digits, $mono ) = @_;
     my $ret = {};
+    my $ver = $self->_version_2_dec( $self->awx_w32_bakefile_version );
     my $suff = ( $self->awx_unicode ? 'u' : '' ) .
-               ( $self->awx_debug ? 'd' : '' );
+               ( $self->awx_debug && $ver <= 2.009 ? 'd' : '' );
 
     my @dlls = grep { m/${digits}\d*${suff}_/ }
                bsd_glob( File::Spec->catfile( $libdir, '*.dll' ) );
@@ -105,15 +106,20 @@ sub awx_configure {
     $config{config}{toolkit} = $self->is_wince ? 'wce' : 'msw';
     $config{shared_library_path} = awx_install_arch_file( $self, "rEpLaCe/lib" );
 
+    $self->awx_w32_find_setup_dir( $self->wx_config( 'cxxflags' ) );
+
+    return %config;
+}
+
+sub awx_w32_find_setup_dir {
+    my( $self, $cxxflags ) = @_;
+
     die "Unable to find setup.h directory"
-      unless $self->wx_config( 'cxxflags' )
-                 =~ m{[/-]I\s*(\S+lib[\\/][\w\\/]+)(?:\s|$)};
+      unless $cxxflags =~ m{[/-]I\s*(\S+lib[\\/][\w\\/]+)(?:\s|$)};
     $self->{awx_setup_dir} = $1;
 
     $self->{awx_data}{version} = $self->awx_w32_bakefile_version
       if -f $self->awx_w32_build_cfg;
-
-    return %config;
 }
 
 sub awx_w32_bakefile_version {
@@ -225,12 +231,11 @@ sub awx_get_package {
     return $package . '_Bakefile';
 }
 
-# MSLU is default when using Unicode *and* it has not
-# been explicitly disabled
+# MSLU is off by default. It Must be explicitly enabled
 sub awx_mslu {
     return $_[0]->args( 'wxWidgets-mslu' )
       if defined $_[0]->args( 'wxWidgets-mslu' );
-    return $_[0]->args( 'wxWidgets-unicode' );
+    return 0;
 }
 
 sub massage_environment {
@@ -246,6 +251,7 @@ package My::Build::Win32_Bakefile;
 
 use strict;
 use Carp;
+use Config;
 # mixin: no use base
 
 sub build_wxwidgets {
@@ -256,9 +262,14 @@ sub build_wxwidgets {
     my $mslu = $self->awx_mslu   ? 'MSLU=1'      : 'MSLU=0';
     my $dbg = $self->awx_debug   ? 'BUILD=debug' : 'BUILD=release';
     my $opt = join ' ', $uni, $mslu, $dbg, 'SHARED=1';
-
-    $opt .= ' ' . $self->notes( 'extraflags' ) if($self->notes( 'extraflags' ));
-
+    
+    if( my $xbuildflags = $self->awx_w32_extra_buildflags ) {
+		$opt .= ' ' . $xbuildflags;
+	}
+    
+    # help windres in x compiler
+    local $ENV{GNUTARGET} = ( $Config{ptrsize} == 8 )  ? 'pe-x86-64' : 'pe-i386';
+    
     chdir File::Spec->catdir( $ENV{WXDIR}, 'build', 'msw' );
     $self->_system( $self->_make_command . ' ' . $opt );
     chdir File::Spec->catdir( $ENV{WXDIR}, 'contrib', 'build', 'stc' );
@@ -267,6 +278,60 @@ sub build_wxwidgets {
     chdir $old_dir;
 }
 
+sub awx_w32_configure_extra_flags {
+    my $self = shift; 
+    return $self->notes( 'extraflags' );
+}
+
+sub awx_w32_extra_buildflags {
+    my $self = shift;
+    my $buildflags = '';
+	my $extraflags = $self->awx_w32_configure_extra_flags;
+	$buildflags .= $extraflags if $extraflags;
+	
+	return $buildflags if !$self->notes('build_wx');
+	
+	
+	# extra flags for vers != 2.8 - that is >= 2.9
+
+	if( $self->notes( 'build_data' )->{data}{version} !~ /^2.8/ ) {
+		if($self->awx_debug) {
+			$buildflags .= ' DEBUG_INFO=default DEBUG_FLAG=1';
+		} else {
+			$buildflags .= ' DEBUG_INFO=0 DEBUG_FLAG=0'; 
+		}
+	}
+
+	# flags for vers == 2.8
+
+	if( $self->notes( 'build_data' )->{data}{version} =~ /^2.8/ ) {
+
+		# do graphicscontext for 2.8 build if requested
+		if( $self->notes( 'graphicscontext' ) ) {
+			$buildflags .= ' USE_GDIPLUS=1';
+		}
+
+	}
+
+	if( my $ldflags = $self->awx_w32_ldflags ) {
+		# only add if user has not specified LDFLAGS in 'extraflags'
+		if( $extraflags !~ / LDFLAGS=/ ) {
+			$buildflags .= qq( LDFLAGS=\"$ldflags\");
+		}
+	}
+
+	if( my $cppflags = $self->awx_w32_cppflags ) {
+		# only add if user has not specified CPPFLAGS in 'extraflags'
+		if( $extraflags !~ / CPPFLAGS=/ ) {
+			$buildflags .= qq( CPPFLAGS=\"$cppflags\");
+		}
+	}
+	
+	return $buildflags;
+	
+}
+
 sub is_wince { 0 }
 
+
 1;
